ModifiedBlackBody — pysm v3.1.dev260

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.1.dev260 »
- ModifiedBlackBody

# ModifiedBlackBody

class `pysm.` `ModifiedBlackBody`(map_I, map_Q, map_U, freq_ref_I, freq_ref_P, map_mbb_index, map_mbb_temperature, nside, has_polarization=True, unit_I=None, unit_Q=None, unit_U=None, unit_mbb_temperature=None, map_dist=None)

  Bases: `pysm.Model`

  This is a model for modified black body emission.

  Attributes
    I_ref, Q_ref, U_ref: ndarray

      Arrays containing the intensity or polarization reference templates at frequency `freq_ref_I` or `freq_ref_P`.

  This function initializes the modified black body model.

  The initialization of this model consists of reading in emission templates from file, reading in spectral parameter maps from file.

  Parameters
    map_I, map_Q, map_U: `pathlib.Path` object

      Paths to the maps to be used as I, Q, U templates.

    unit_*string or Unit

      Unit string or Unit object for all input FITS maps, if None, the input file should have a unit defined in the FITS header.

    freq_ref_I, freq_ref_P: Quantity or string

      Reference frequencies at which the intensity and polarization templates are defined. They should be a astropy Quantity object or a string (e.g. “1500 MHz”) compatible with GHz.

    map_mbb_index: `pathlib.Path` object or scalar value

      Path to the map to be used as the power law index for the dust opacity in a modified blackbody model, for a constant value use a float or an integer

    map_mbb_temperature: `pathlib.Path` object or scalar

      Path to the map to be used as the temperature of the dust in a modified blackbody model. For a constant value use a float or an integer

    nside: int

      Resolution parameter at which this model is to be calculated.

  Methods Summary

  `get_emission`(self, freqs[, weights]) | This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

  Methods Documentation

  `get_emission`(self, freqs:Unit("GHz"), weights=None) -> Unit("uK_RJ")

    This function evaluates the component model at a either a single frequency, an array of frequencies, or over a bandpass.

    Parameters
      freqs: scalar or array astropy.units.Quantity

        Frequency at which the model should be evaluated, in a frequency which can be converted to GHz using astropy.units. If an array of frequencies is provided, integrate using trapz with a equal weighting, i.e. simulate a top-hat bandpass.

      weights: np.array, optional

        Array of weights describing the frequency response of the instrument, i.e. the bandpass. Weights are normalized and applied in Jy/sr.

    Returns
      outputastropy.units.Quantity

        Simulated map at the given frequency or integrated over the given bandpass. The shape of the output is (3,npix) for polarized components, (1,npix) for temperature-only components. Output is in `uK_RJ`.